import ssl
import sys

EXIT_OPERATIONAL = 1
EXIT_FIPS_NONCAPABLE = 2

if __name__ == "__main__":
    ctx_c = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
    ctx_s = ssl.SSLContext(ssl.PROTOCOL_TLS_SERVER)
    ciphers = ctx_c.get_ciphers() + ctx_s.get_ciphers()

    for c in ciphers:
        cipher_suite = None

        if "name" in c:
            # Some simple normalization
            # e.g. "TLS_DHE_DSS_WITH_AES_128_CBC_SHA256" to "tls-dhe-dss-with-aes-128-cbc-sha256"
            cipher_suite = c["name"].lower().replace("_", "-")

        if not cipher_suite:
            # We could not get the cipher suite name, something went wrong
            sys.exit(EXIT_OPERATIONAL)

        # Check Symmetric cipher
        if not ("aes" in cipher_suite or ("des" in cipher_suite and "3" in cipher_suite)):
            # Neither AES nor 3DES is used for symmetric encryption
            print(f"Error: found non-FIPS cipher suite- {cipher_suite}", file=sys.stderr)
            sys.exit(EXIT_FIPS_NONCAPABLE)

        # Check Integrity protection algorithm a.k.a. MAC
        mac = cipher_suite.split("-")[-1]

        if not ("sha" in mac or "ccm" in mac or "gcm" in mac):
            print(f"Error: found non-FIPS cipher suite- {cipher_suite}", file=sys.stderr)
            sys.exit(EXIT_FIPS_NONCAPABLE)

if len(ciphers) == 0:
    # There were no ciphers. Something went wrong
    sys.exit(EXIT_OPERATIONAL)

# If we got here, then all ciphers are FIPS approved
sys.exit(0)
