#!/bin/sh
IMAGE="$1"

EXIT_NA=0
EXIT_OPERATIONAL=1  # i.e. unknown
EXIT_FIPS_NONCAPABLE=2
EXIT_FIPS_CAPABLE=3
EXIT_FIPS_ENFORCED=4
SHELL=/bin/sh
DOCKER_HOST_DIR=$(docker inspect "$(hostname)" | jq -r '.[] | .GraphDriver | .Data | .MergedDir') # We need this because we are already 1 level deep

if ! docker run --rm --entrypoint "${SHELL}" "${IMAGE}" -c "true"
then
	echo "Could not run ${SHELL} in ${IMAGE}"
	# TODO: implement check for distroless containers (from scratch)
	exit "${EXIT_OPERATIONAL}"
fi

if JAVA_VERSION=$(docker run --rm -t --entrypoint "${SHELL}" "${IMAGE}" -c "java -version")
then
	echo "Java found"

	# This is required only in Java 17
	JAVA17_OPTS=""
	if echo "${JAVA_VERSION}" | grep "build 17"
	then
		JAVA17_OPTS="--add-exports java.base/sun.security.provider=ALL-UNNAMED"
	fi

	docker run --rm --entrypoint "${SHELL}" -v "${DOCKER_HOST_DIR}/${PWD}/additional:/check" "${IMAGE}" -i -c 'java -jar /check/CheckFIPS.jar'
	EXIT_CODE=$?
	if test ${EXIT_CODE} -eq 0
	then
		echo "Java is in FIPS mode"
		exit "${EXIT_FIPS_ENFORCED}"
	elif test ${EXIT_CODE} -eq 3
	then
		# We got a non-FIPS algorithm above
	
		# Try manually forcing FIPS
		if docker run --rm --entrypoint "${SHELL}" -v "${DOCKER_HOST_DIR}/${PWD}/additional:/check" -w "/check" -e JAVA17_OPTS="${JAVA17_OPTS}" "${IMAGE}" -i -c 'JAVA_CLASSPATH=${JAVA_CLASSPATH}:./CheckFIPS.jar java-fips ${JAVA17_OPTS} CheckFIPS'
		then
			exit "${EXIT_FIPS_CAPABLE}"
		else
			exit "${EXIT_FIPS_NONCAPABLE}"
		fi
	else
		# Something must have gone wrong. We should not be here
		exit "${EXIT_OPERATIONAL}"
	fi
else
	echo "Java not found"
	exit "${EXIT_NA}"
fi

# We should not arrive here. Commenting out for shellcheck.
# exit "${EXIT_NA}"
